leaftools.list_written_durations_of_leaves_in_expr
==================================================

.. autofunction:: abjad.tools.leaftools.list_written_durations_of_leaves_in_expr.list_written_durations_of_leaves_in_expr
